@@ -13,6 +13,7 @@ import pytest
 from lazy_object_proxy.utils import await_
 
 pypyxfail = pytest.mark.xfail('hasattr(sys, "pypy_version_info")')
+graalpyxfail = pytest.mark.xfail('sys.implementation.name == "graalpy"')
 
 
 class AsyncYieldFrom:
@@ -75,6 +76,7 @@ def test_gen_1(lop):
     assert not hasattr(gen, '__await__')
 
 
+@graalpyxfail
 def test_func_1(lop):
     async def foo():
         return 10
@@ -95,11 +97,12 @@ def test_func_1(lop):
     assert not bool(bar.__code__.co_flags & inspect.CO_COROUTINE)
 
 
+@graalpyxfail
 def test_func_2(lop):
     async def foo():
         raise StopIteration
 
-    with pytest.raises(RuntimeError, match="coroutine raised StopIteration"):
+    with pytest.raises(RuntimeError, match='coroutine raised StopIteration'):
         run_async(lop.Proxy(foo))
 
 
@@ -269,16 +272,18 @@ def test_func_11(lop):
     coro.close()
 
 
+@graalpyxfail
 def test_func_12(lop):
     async def g():
         i = me.send(None)
         await foo
 
     me = lop.Proxy(g)
-    with pytest.raises(ValueError, match="coroutine already executing"):
+    with pytest.raises(ValueError, match='coroutine already executing'):
         me.send(None)
 
 
+@graalpyxfail
 def test_func_13(lop):
     async def g():
         pass
@@ -290,6 +295,7 @@ def test_func_13(lop):
     coro.close()
 
 
+@graalpyxfail
 def test_func_14(lop):
     @types.coroutine
     def gen():
@@ -303,7 +309,7 @@ def test_func_14(lop):
 
     c = lop.Proxy(coro)
     c.send(None)
-    with pytest.raises(RuntimeError, match="coroutine ignored GeneratorExit"):
+    with pytest.raises(RuntimeError, match='coroutine ignored GeneratorExit'):
         c.close()
 
 
@@ -498,7 +504,7 @@ def test_await_1(lop):
     async def foo():
         await 1
 
-    with pytest.raises(TypeError, match="object int can.t.*await"):
+    with pytest.raises(TypeError, match='int.*can.t.*await'):
         run_async(lop.Proxy(foo))
 
 
@@ -506,7 +512,7 @@ def test_await_2(lop):
     async def foo():
         await []
 
-    with pytest.raises(TypeError, match="object list can.t.*await"):
+    with pytest.raises(TypeError, match='list.*can.t.*await'):
         run_async(lop.Proxy(foo))
 
 
@@ -536,7 +542,7 @@ def test_await_5(lop):
     async def foo():
         return await lop.Proxy(Awaitable)
 
-    with pytest.raises(TypeError, match="__await__.*returned non-iterator of type"):
+    with pytest.raises(TypeError, match='__await__.*returned non-iterator of type'):
         run_async(lop.Proxy(foo))
 
 
@@ -644,7 +650,7 @@ def test_await_12(lop):
     async def foo():
         return await lop.Proxy(Awaitable)
 
-    with pytest.raises(TypeError, match=r"__await__\(\) returned a coroutine"):
+    with pytest.raises(TypeError, match=r'__await__\(\) returned a coroutine'):
         run_async(lop.Proxy(foo))
 
     c.close()
@@ -658,7 +664,7 @@ def test_await_13(lop):
     async def foo():
         return await lop.Proxy(Awaitable)
 
-    with pytest.raises(TypeError, match="__await__.*returned non-iterator of type"):
+    with pytest.raises(TypeError, match='__await__.*returned non-iterator of type'):
         run_async(lop.Proxy(foo))
 
 
@@ -713,7 +719,7 @@ def test_await_15(lop):
     coro = lop.Proxy(coroutine)
     coro.send(None)
 
-    with pytest.raises(RuntimeError, match="coroutine is being awaited already"):
+    with pytest.raises(RuntimeError, match='coroutine is being awaited already'):
         waiter(coro).send(None)
 
 
@@ -749,7 +755,7 @@ def test_with_1(lop):
                 return True
 
     async def foo():
-        async with lop.Proxy(lambda: Manager("A")) as a, lop.Proxy(lambda: Manager("B")) as b:
+        async with lop.Proxy(lambda: Manager('A')) as a, lop.Proxy(lambda: Manager('B')) as b:
             await lop.Proxy(lambda: AsyncYieldFrom([('managers', a.name, b.name)]))
             1 / 0
 
@@ -769,7 +775,7 @@ def test_with_1(lop):
     ]
 
     async def foo():
-        async with lop.Proxy(lambda: Manager("A")) as a, lop.Proxy(lambda: Manager("C")) as c:
+        async with lop.Proxy(lambda: Manager('A')) as a, lop.Proxy(lambda: Manager('C')) as c:
             await lop.Proxy(lambda: AsyncYieldFrom([('managers', a.name, c.name)]))
             1 / 0
 
@@ -777,6 +783,7 @@ def test_with_1(lop):
         run_async(lop.Proxy(foo))
 
 
+@graalpyxfail
 def test_with_2(lop):
     class CM:
         def __aenter__(self):
@@ -845,6 +852,7 @@ def test_with_5(lop):
 
 
 @pypyxfail
+@graalpyxfail
 def test_with_6(lop):
     class CM:
         def __aenter__(self):
@@ -857,12 +865,13 @@ def test_with_6(lop):
         async with lop.Proxy(CM):
             pass
 
-    with pytest.raises(TypeError, match="'async with' received an object from __aenter__ " "that does not implement __await__: int"):
+    with pytest.raises(TypeError, match="'async with' received an object from __aenter__ that does not implement __await__: int"):
         # it's important that __aexit__ wasn't called
         run_async(lop.Proxy(foo))
 
 
 @pypyxfail
+@graalpyxfail
 def test_with_7(lop):
     class CM:
         async def __aenter__(self):
@@ -879,7 +888,7 @@ def test_with_7(lop):
     try:
         run_async(lop.Proxy(foo))
     except TypeError as exc:
-        assert re.search("'async with' received an object from __aexit__ " "that does not implement __await__: int", exc.args[0])
+        assert re.search("'async with' received an object from __aexit__ that does not implement __await__: int", exc.args[0])
         assert exc.__context__ is not None
         assert isinstance(exc.__context__, ZeroDivisionError)
     else:
@@ -887,6 +896,7 @@ def test_with_7(lop):
 
 
 @pypyxfail
+@graalpyxfail
 def test_with_8(lop):
     CNT = 0
 
@@ -903,7 +913,7 @@ def test_with_8(lop):
         async with lop.Proxy(CM):
             CNT += 1
 
-    with pytest.raises(TypeError, match="'async with' received an object from __aexit__ " "that does not implement __await__: int"):
+    with pytest.raises(TypeError, match="'async with' received an object from __aexit__ that does not implement __await__: int"):
         run_async(lop.Proxy(foo))
     assert CNT == 1
 
@@ -915,7 +925,7 @@ def test_with_8(lop):
                 CNT += 1
                 break
 
-    with pytest.raises(TypeError, match="'async with' received an object from __aexit__ " "that does not implement __await__: int"):
+    with pytest.raises(TypeError, match="'async with' received an object from __aexit__ that does not implement __await__: int"):
         run_async(lop.Proxy(foo))
     assert CNT == 2
 
@@ -927,7 +937,7 @@ def test_with_8(lop):
                 CNT += 1
                 continue
 
-    with pytest.raises(TypeError, match="'async with' received an object from __aexit__ " "that does not implement __await__: int"):
+    with pytest.raises(TypeError, match="'async with' received an object from __aexit__ that does not implement __await__: int"):
         run_async(lop.Proxy(foo))
     assert CNT == 3
 
@@ -938,7 +948,7 @@ def test_with_8(lop):
             CNT += 1
             return
 
-    with pytest.raises(TypeError, match="'async with' received an object from __aexit__ " "that does not implement __await__: int"):
+    with pytest.raises(TypeError, match="'async with' received an object from __aexit__ that does not implement __await__: int"):
         run_async(lop.Proxy(foo))
     assert CNT == 4
 
@@ -990,6 +1000,7 @@ def test_with_10(lop):
         pytest.fail('exception from __aexit__ did not propagate')
 
 
+@graalpyxfail
 def test_with_11(lop):
     CNT = 0
 
@@ -1032,6 +1043,7 @@ def test_with_12(lop):
     run_async(lop.Proxy(foo))
 
 
+@graalpyxfail
 def test_with_13(lop):
     CNT = 0
 
@@ -1224,7 +1236,7 @@ def test_for_6(lop):
         I += 1000
 
     with warnings.catch_warnings():
-        warnings.simplefilter("error")
+        warnings.simplefilter('error')
         # Test that __aiter__ that returns an asynchronous iterator
         # directly does not throw any warnings.
         run_async(main())
@@ -1309,7 +1321,7 @@ def test_for_8(lop):
 
     with pytest.raises(ZeroDivisionError):
         with warnings.catch_warnings():
-            warnings.simplefilter("error")
+            warnings.simplefilter('error')
             # Test that if __aiter__ raises an exception it propagates
             # without any kind of warning.
             run_async(lop.Proxy(foo))
@@ -1622,7 +1634,7 @@ def test_pickle(lop):
         aw.close()
 
 
-@pytest.mark.skipif("sys.version_info[1] < 8")
+@pytest.mark.skipif('sys.version_info[1] < 8')
 def test_for_assign_raising_stop_async_iteration(lop):
     class BadTarget:
         def __setitem__(self, key, value):
@@ -1662,7 +1674,7 @@ def test_for_assign_raising_stop_async_iteration(lop):
     assert run_async(run_gen()) == ([], 'end')
 
 
-@pytest.mark.skipif("sys.version_info[1] < 8")
+@pytest.mark.skipif('sys.version_info[1] < 8')
 def test_for_assign_raising_stop_async_iteration_2(lop):
     class BadIterable:
         def __iter__(self):
@@ -1733,6 +1745,8 @@ def test_asyncio_1(lop):
         pass
     finally:
         loop.close()
-        asyncio.set_event_loop_policy(None)
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore', DeprecationWarning)
+            asyncio.set_event_loop_policy(None)
 
     assert buffer == [1, 2, 'MyException']
